# ggcmpy Documentation

_Python Utilities for the OpenGGCM Global Magnetosphere Code_

```{toctree}
:maxdepth: 2
:hidden:

Getting Started <getting-started-guide/index>
API <api/index>

OpenGGCM <openggcm/index>
```

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
